@@ -59,6 +59,8 @@ static CompilerTestSet testCases = {"test1.cpp",
                                     "test15.cpp",
                                     "test16.h",
                                     "test16.cpp",
+                                    "test17.h",
+                                    "test17.cpp",
                                     "test_dpointer.cpp",
                                     "test_dpointer.h",
                                     "test_qdebugcategory.cpp",
@@ -81,6 +83,8 @@ static CompilerTestSet testCases = {"test1.cpp",
                                     "test_param_minmax.h",
                                     "test_subgroups.cpp",
                                     "test_subgroups.h",
+                                    "test_time.cpp",
+                                    "test_time.h",
                                     nullptr};
 
 static CompilerTestSet testCasesToRun = {"Test1",
@@ -100,6 +104,7 @@ static CompilerTestSet testCasesToRun = {"Test1",
                                          "Test14",
                                          "Test15",
                                          "Test16",
+                                         "Test17",
                                          "test_enums_and_properties",
                                          "test_dpointer",
                                          "test_qdebugcategory",
@@ -132,6 +137,7 @@ static CompilerTestSet testCasesToRun = {"Test1",
                                          "test_signal_cmake",
                                          "test_emptyentries_cmake",
                                          "test_subgroups_cmake",
+                                         "test_time_cmake",
                                          nullptr};
 
 #if 0
