@@ -60,7 +60,7 @@ static const QString s_string_entry6{};
 static const char s_utf8bit_entry[] = "Hello äöü";
 static const QString s_translated_string_entry1{QStringLiteral("bonjour")};
 static const QByteArray s_bytearray_entry{"\x00\xff\x7f\x3c abc\x00\x00", 10};
-static const char s_escapekey[] = " []\0017[]==]";
+static const char s_escapekey[] = " []\0017[]==\\]";
 static const char s_escape_entry[] = "[]\170[]]=3=]\\] ";
 static const double s_double_entry{123456.78912345};
 static const float s_float_entry{123.567f};
@@ -69,6 +69,13 @@ static const QSize s_size_entry{10, 20};
 static const QRect s_rect_entry{10, 23, 5321, 13};
 static const QDateTime s_date_time_entry{QDate{2002, 06, 23}, QTime{12, 55, 40}};
 static const QDateTime s_date_time_with_ms_entry{QDate{2002, 06, 23}, QTime{12, 55, 40, 532}};
+static const QDateTime s_date_time_utc = QDateTime::currentDateTimeUtc();
+static const QDateTime s_date_time_tz = [] {
+    auto dt = QDateTime::currentDateTime();
+    dt.setTimeZone(QTimeZone("EST"));
+    return dt;
+}();
+static const QTime s_time_entry(21, 42, 37);
 static const QStringList s_stringlist_entry{QStringLiteral("Hello,"), QStringLiteral("World")};
 static const QStringList s_stringlist_empty_entry{};
 static const QStringList s_stringlist_just_empty_element{QString{}};
@@ -162,6 +169,9 @@ void KConfigTest::initTestCase()
     cg.writeEntry("dateTimeEntry", s_date_time_entry);
     cg.writeEntry("dateEntry", s_date_time_entry.date());
     cg.writeEntry("dateTimeWithMSEntry", s_date_time_with_ms_entry);
+    cg.writeEntry("dateTimeUtc", s_date_time_utc);
+    cg.writeEntry("dateTimeTz", s_date_time_tz);
+    cg.writeEntry("timeEntry", s_time_entry);
 
     KConfigGroup ct = cg;
     cg = KConfigGroup(&ct, QStringLiteral("Nested Group 1"));
@@ -262,25 +272,6 @@ void KConfigTest::cleanupTestCase()
     }
 }
 
-static QList<QByteArray> readLinesFrom(const QString &path)
-{
-    QFile file(path);
-    const bool opened = file.open(QIODevice::ReadOnly | QIODevice::Text);
-    QList<QByteArray> lines;
-    if (!opened) {
-        qWarning() << "Failed to open" << path;
-        return lines;
-    }
-    QByteArray line;
-    do {
-        line = file.readLine();
-        if (!line.isEmpty()) {
-            lines.append(line);
-        }
-    } while (!line.isEmpty());
-    return lines;
-}
-
 static const QString s_defaultArg = s_test_subdir + QLatin1String("kconfigtest");
 static QList<QByteArray> readLines(const QString &fileName = s_defaultArg)
 {
@@ -620,7 +611,10 @@ void KConfigTest::testComplex()
     QCOMPARE(sc3.readEntry("dateTimeEntry", QDateTime()).toString(Qt::ISODateWithMs), s_date_time_entry.toString(Qt::ISODateWithMs));
     QCOMPARE(sc3.readEntry("dateEntry", QDate()).toString(Qt::ISODate), s_date_time_entry.date().toString(Qt::ISODate));
     QCOMPARE(sc3.readEntry("dateTimeWithMSEntry", QDateTime()).toString(Qt::ISODateWithMs), s_date_time_with_ms_entry.toString(Qt::ISODateWithMs));
+    QCOMPARE(sc3.readEntry("dateTimeTz", QDateTime()).timeZone(), s_date_time_tz.timeZone());
+    QCOMPARE(sc3.readEntry("dateTimeUtc", QDateTime()).timeRepresentation().id(), s_date_time_utc.timeRepresentation().id());
     QCOMPARE(sc3.readEntry("dateTimeEntry", QDate()), s_date_time_entry.date());
+    QCOMPARE(sc3.readEntry("timeEntry", QTime()), s_time_entry);
 }
 
 void KConfigTest::testEnums()
@@ -692,6 +686,7 @@ void KConfigTest::testInvalid()
     QVERIFY(sc3.readEntry("badList", QRect()) == QRect());
     QVERIFY(sc3.readEntry("badList", QSize()) == QSize());
     QVERIFY(sc3.readEntry("badList", QDate()) == QDate());
+    QVERIFY(sc3.readEntry("badList", QTime()) == QTime());
     QVERIFY(sc3.readEntry("badList", QDateTime()) == QDateTime());
 
     // 2 element list
@@ -700,6 +695,7 @@ void KConfigTest::testInvalid()
 
     QVERIFY(sc3.readEntry("badList", QRect()) == QRect());
     QVERIFY(sc3.readEntry("badList", QDate()) == QDate());
+    QVERIFY(sc3.readEntry("badList", QTime()) == QTime());
     QVERIFY(sc3.readEntry("badList", QDateTime()) == QDateTime());
 
     // 3 element list
@@ -710,6 +706,7 @@ void KConfigTest::testInvalid()
     QVERIFY(sc3.readEntry("badList", QRect()) == QRect());
     QVERIFY(sc3.readEntry("badList", QSize()) == QSize());
     QVERIFY(sc3.readEntry("badList", QDate()) == QDate()); // out of bounds
+    QVERIFY(sc3.readEntry("badList", QTime()) == QTime());
     QVERIFY(sc3.readEntry("badList", QDateTime()) == QDateTime());
 
     // 4 element list
@@ -719,6 +716,7 @@ void KConfigTest::testInvalid()
     QVERIFY(sc3.readEntry("badList", QPoint()) == QPoint());
     QVERIFY(sc3.readEntry("badList", QSize()) == QSize());
     QVERIFY(sc3.readEntry("badList", QDate()) == QDate());
+    QVERIFY(sc3.readEntry("badList", QTime()) == QTime());
     QVERIFY(sc3.readEntry("badList", QDateTime()) == QDateTime());
 
     // 5 element list
@@ -730,6 +728,7 @@ void KConfigTest::testInvalid()
     QVERIFY(sc3.readEntry("badList", QRect()) == QRect());
     QVERIFY(sc3.readEntry("badList", QSize()) == QSize());
     QVERIFY(sc3.readEntry("badList", QDate()) == QDate());
+    QVERIFY(sc3.readEntry("badList", QTime()) == QTime());
     QVERIFY(sc3.readEntry("badList", QDateTime()) == QDateTime());
 
     // 6 element list
@@ -739,6 +738,7 @@ void KConfigTest::testInvalid()
     QVERIFY(sc3.readEntry("badList", QPoint()) == QPoint());
     QVERIFY(sc3.readEntry("badList", QRect()) == QRect());
     QVERIFY(sc3.readEntry("badList", QSize()) == QSize());
+    QVERIFY(sc3.readEntry("badList", QTime()) == QTime());
 }
 
 void KConfigTest::testChangeGroup()
