@@ -70,6 +70,7 @@ void KConfigHeaderGenerator::doClassDefinition()
         createSetters(entry);
         createProperties(entry, returnType);
         createImmutableProperty(entry);
+        createDefaultValueProperty(entry, returnType);
         createGetters(entry, returnType);
         createImmutableGetters(entry);
         createDefaultValueMember(entry);
@@ -193,6 +194,9 @@ void KConfigHeaderGenerator::implementChoiceEnums(const CfgEntry *entry, const C
     } else if (!choices.external()) {
         // Create a named enum
         stream() << whitespace() << "enum " << enumName(entry->name, entry->choices) << " { " << values.join(QStringLiteral(", ")) << " };\n";
+        if (cfg().generateProperties) {
+            stream() << whitespace() << "Q_ENUM(" << enumName(entry->name, entry->choices) << ")\n";
+        }
     }
 }
 
@@ -424,6 +428,22 @@ void KConfigHeaderGenerator::createImmutableProperty(const CfgEntry *entry)
     stream() << " CONSTANT)\n";
 }
 
+void KConfigHeaderGenerator::createDefaultValueProperty(const CfgEntry *entry, const QString &returnType)
+{
+    if (!cfg().generateProperties) {
+        return;
+    }
+
+    if (!((cfg().allDefaultGetters || cfg().defaultGetters.contains(entry->name)) && !entry->defaultValue.isEmpty())) {
+        return;
+    }
+
+    stream() << whitespace();
+    stream() << "Q_PROPERTY(" << returnType << ' ' << getDefaultFunction(entry->name);
+    stream() << " READ " << getDefaultFunction(entry->name);
+    stream() << " CONSTANT)\n";
+}
+
 void KConfigHeaderGenerator::createSetters(const CfgEntry *entry)
 {
     // Manipulator
